/**************************************************************
            ==================================
            Star Wars - The POV-Ray Collection
            ==================================

TIE_DEF.INC - 3D model description file for use with the
Persistence of Vision Ray-Tracer, v3.0

POV-Ray code copyright (c) 1997 D M Beattie

This model is provided for personal use only. Any use of this
model for commercial gain or profit is strictly forbidden -
please see the accompanying README.TXT and Conditions of Use
before using or distributing this model.

'Star Wars' and all associated images, designs and trademarks,
(including the designs of the vehicles and objects depicted in
the Star Wars POV-Ray Collection, except where otherwise
stated) are copyright (c) 1997 Lucasfilm Ltd.

**************************************************************/

// TIE_DEF.INC - TIE Defender model definition for POV-Ray v3.0

#declare TD_Tex1=texture { //Lighter Grey Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.65,0.65,0.67>]
      [0.5 colour rgb <0.62,0.62,0.66>]
      [1.0 colour rgb <0.63,0.64,0.67>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TD_Tex2=texture { //Medium Gray Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.45,0.45,0.5>]
      [0.5 colour rgb <0.47,0.47,0.52>]
      [1.0 colour rgb <0.42,0.42,0.5>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TD_Tex3=texture { // Dark Grey Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.3,0.3,0.35>]
      [0.5 colour rgb <0.28,0.27,0.31>]
      [1.0 colour rgb <0.29,0.31,0.35>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TD_Screen_Tex = texture {
  pigment {colour rgb 0.01}
  finish {specular 0.5 roughness 0.01 reflection 0.3}
}

#declare TD_SolarPanel = texture { //'Striped' texture on solar panels
  pigment {
    gradient <0,1,0>
    colour_map {
      [0.0 colour rgb <0.2,0.2,0.21>]
      [0.8 colour rgb <0.2,0.2,0.21>]
      [0.8 colour rgb 0.8]
      [1 colour rgb 0.8]
    }
    scale <1,0.05,1>
    translate <0,20,0>
  }
  finish {
    specular 0.3
    roughness 0.01
  }
}

#declare TD_PanelMount = object {
  union {
    object {cone {<0,0,0>, 0.1, <0,0.2,0>, 0.01} texture {TD_Tex2}}
    object {cylinder {<0,0,0>, <0,0.5,0>, 0.35} texture {TD_Tex3}}
    object {cylinder {<0,0,0>, <0,0.7,0>, 0.3} texture {TD_Tex3}}
    object {cylinder {<0,0,0>, <0,2,0>, 0.25} texture {TD_Tex3}}
    object {cone {<0,1.5,0>, 0.3, <0,2,0>, 0.5} texture {TD_Tex2}}
  }
  rotate <0,0,-90>
  rotate <90,0,0>
  scale <-1,1,1>
}

#declare TD_PanelA = object {
  #declare TDA = <0,0,5>
  #declare TDB = <0,2,1.5>
  #declare TDC = <0,2,-1.25>
  #declare TDD = <0,0,-2.5>
  #declare TDE = <0,0,0.75>
  #declare TDF = <0,0,-0.75>
  #declare TDR1 = 0.05
  #declare TDR2 = 0.02
  union {
    object {
      intersection {
        object {
          union {
            object {cylinder {TDA,TDB,TDR1}}
            object {cylinder {TDB,TDC,TDR1}}
            object {cylinder {TDC,TDD,TDR1}}
            object {cylinder {TDD,TDE,TDR1}}
            object {cylinder {TDE,TDA,TDR1}}
            object {cylinder {TDE,TDB,TDR1}}
            object {cylinder {TDC,TDF,TDR1}}
            object {sphere {TDA,TDR1}}
            object {sphere {TDB,TDR1}}
            object {sphere {TDC,TDR1}}
            object {sphere {TDD,TDR1}}
            object {sphere {TDE,TDR1}}
          }
          scale <5,1,1>
        }
        object {box {<-0.025, -1, -4>, <0.025, 3, 6>}}
      }
      texture {TD_Tex1}
    }
    object {
      intersection {
        object {
          union {
            object {cylinder {TDA,TDB,TDR2}}
            object {cylinder {TDB,TDC,TDR2}}
            object {cylinder {TDC,TDD,TDR2}}
            object {cylinder {TDD,TDE,TDR2}}
            object {cylinder {TDE,TDA,TDR2}}
            object {cylinder {TDE,TDB,TDR2}}
            object {cylinder {TDC,TDF,TDR2}}
            object {sphere {TDA,TDR2}}
            object {sphere {TDB,TDR2}}
            object {sphere {TDC,TDR2}}
            object {sphere {TDD,TDR2}}
            object {sphere {TDE,TDR2}}
          }
          scale <5,1,1>
        }
        object {box {<-0.05, -1, -4>, <0.05, 3, 6>}}
      }
      texture {TD_Tex2}
    }
    object {
      mesh {
        triangle {TDA,TDB,TDE}
        triangle {TDC,TDB,TDE}
        triangle {TDC,TDD,TDE}
      }
      texture {TD_SolarPanel}
    }
  }
  rotate <0,0,-40>
  translate <0,0.75,0>
}
#declare TD_PanelCentre = object {
  union {
    object {
      intersection {
        object {cone {<0,-0.001,0>, 0.3, <0,0.0501,0>, 0.25} scale <1,1,100> rotate <0,25,0>}
        object {cone {<0,-0.001,0>, 0.3, <0,0.0501,0>, 0.25} scale <1,1,100> rotate <0,-25,0>}
        object {cone {<0,0,0>, 0.2, <0,0.05,0>, 0.15} scale <100,1,2> rotate <0,0,0>}
      }
      texture {TD_Tex2}
    }
    object {
      intersection {
        object {cone {<0,-0.001,0>, 0.25, <0,0.0501,0>, 0.2} scale <0.5,0.2,50> rotate <0,25,0>}
        object {cone {<0,-0.001,0>, 0.25, <0,0.0501,0>, 0.2} scale <0.5,0.2,50> rotate <0,-25,0>}
        object {cone {<0,0,0>, 0.2, <0,0.05,0>, 0.15} scale <50,0.2,1> rotate <0,0,0>}
      }
      translate <0,0.05,0>
      texture {TD_Tex3}
    }
    object {cylinder {<0,0,0>, <0,0.08,0>, 0.1} texture {TD_Tex2}}
    object {cone {<0,0.08,0>, 0.1, <0,0.1, 0>, 0.05} texture {TD_Tex2}}
  }
}

#declare TD_PanelB = object {
  union {
    object {box {<-0.005, -0.75, -0.75>, <0.005, 0.75, 0.75>} texture {TD_SolarPanel}} // Main Section
    object {box {<-0.025, -0.75, -0.755>, <0.025, 0.75, -0.745>} texture {TD_Tex1}}
    object {box {<-0.05, -0.75, -0.775>, <0.05, 0.75, -0.725>} texture {TD_Tex2}}
    object {box {<-0.025, -0.75, 0.745>, <0.025, 0.75, 0.755>} texture {TD_Tex1}}
    object {box {<-0.05, -0.75, 0.725>, <0.05, 0.75, 0.775>} texture {TD_Tex2}}
    object {TD_PanelCentre rotate <0,0,90> scale <1,1.5,1.5>} //Inner detail
  }
}

#declare TD_Panel = object {
  union {
    object {TD_PanelA}
    object {TD_PanelA scale <1,-1,1>}
    object {TD_PanelB}
    object {TD_PanelMount}
  }
}
#declare TD_Screen = object {
  difference {
    object {cone {<0,0,1.036>, 0.7, <0,0,1.2>, 0.3}}
    object {cone {<0,0,1.036>, 0.69, <0,0,1.19>, 0.29}}
  }
  texture {TD_Screen_Tex}
}

#declare TD_ScreenFrame = object {
  union {
    object {torus {0.7,0.015} rotate <90,0,0> translate <0,0,1.036>}
    object {torus {0.3,0.015} rotate <90,0,0> translate <0,0,1.2>}
    #declare Count = 0
    #while (Count < 360)
    object {
      cylinder {<0,0.7,1.036>, <0,0.3,1.2>, 0.015}
      rotate <0,0,Count>
    }
    #declare Count = Count + (360/8)
    #end
  }
  texture {TD_Tex2}
}

#declare Cannon = object {
  union {
    object {cylinder {<0,0,0>, <0,0,0.4>, 0.05} texture {TD_Tex3}}
    object {cylinder {<0,0,0>, <0,0,0.5>, 0.04} texture {TD_Tex3}}
    object {
      difference {
        object {cylinder {<0,0,0>, <0,0,0.65>, 0.035} texture {TD_Tex2}}
        object {cylinder {<0,0,0.5>, <0,0,0.66>, 0.03} texture {TD_Tex3}}
      }
    }
  }
}

#declare TD_Cockpit = object {
  union {
    object { //Main cockpit shape
      difference {
        object {sphere {<0,0,0>, 1.25}}
        object {sphere {<0,0,0>, 1.15}}
        object {cylinder {<0,0,0>, <0,0,2>, 0.7}}
        object {plane {<0,-1,0>, -1}} //Top cut-off for exit hatch
        object {cylinder {<0,0,-0.81>, <0,0,-1.4>, 0.55} texture {pigment {colour rgb 0.15}}}
        object {cylinder {<-0.25, -1, 0.5>, <-0.25, -1, 1>, 0.075}}
        object {cylinder {<0.25, -1, 0.5>, <0.25, -1, 1>, 0.075}}
        object { // Cutaways for laser cannon mounting
          intersection {
            object {
              union {
                object {cylinder {<-0.25, 0, 0.5>, <-0.25, 0, 1>, 0.075}}
                object {cylinder {<0.25, 0, 0.5>, <0.25, 0, 1>, 0.075}}
              }
            }
            object {plane {<0,1,0>, 0}}
          }
          scale <1,3,1>
          translate <0,-1,0>
        }
      }
      texture {
        material_map {
          tga "tcpmap.tga" once
          texture {TD_Tex2} //pigment {colour rgb <1,0,0>}}
          texture {TD_Tex3} //pigment {colour rgb 0.7}}
        }
        translate <-0.5, -0.5, 0>
        scale 2.5
      }
    }
    object {Cannon translate <-0.25,-1.025,0.5> scale <1,1,1>}
    object {Cannon translate <-0.25,-1.025,0.5> scale <-1,1,1>}
    object { // Rear end
      difference {
        object {cone {<0,0,-0.8>, 0.85, <0,0,-1.3>, 0.6}}
        object {cylinder {<0,0,-1.15>, <0,0,-1.4>, 0.5} texture {pigment {colour rgb 0.15}}}
      }
      texture {TD_Tex2}
      translate <0,0,-1>
    }
    object {
      cylinder {<0,0,-0.8>, <0,0,-1.8>, 0.85}
      texture {TD_Tex2}
    }
    object { //Detail on top of rear end
      union {
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-15>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-25>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-35>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-45>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,15>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,25>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,35>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,45>}
      }
      texture {pigment {colour rgb 0.25}}
      translate <0,0,-1>
    }
    object {
      difference {
        object {
          union {
            object {cylinder {<0,0,-1>, <0,0,-1.3>, 0.3}}
            #declare Count = 0
            #while (Count < 360)
            object {
              box {<-0.025,-0.6,-1.3>, <0.025, 0.6, -1>}
               rotate <0,0,Count>
            }
            #declare Count = Count + 30
            #end
          }
        }
        object {cylinder {<0,0,-1.15>, <0,0,-2>, 0.15} texture {pigment {colour rgb 0.15}}}
      }
      texture {TD_Tex2}
      translate <0,0,-1>
    }
    object {
      intersection {
        object {box {<-1.2, -0.15, -1.1>, <1.2, 0.15, 0>}}
        object {sphere {<0,0,0>, 1.4}}
      }
      texture {pigment {colour rgb 0.15}}
    }
    object {
      difference {
        object {sphere {<0,0.01,0>, 1.225}}
        object {plane {<0,1,0>, 1.025}}
      }
      texture {TD_Tex2}
    }
    object {
      difference {
        object {sphere {<0,0.01,0>, 1.25}}
        object {plane {<0,1,0>, 1.025}}
        object {box {<-0.4, 1.1, -2>, <-0.2, 1.5, 0.2>}}
        object {box {<0.4, 1.1, -2>, <0.2, 1.5, 0.2>}}
        object {box {<-0.9, 1.1, -2>, <-0.45, 1.5, 0>}}
        object {box {<0.9, 1.1, -2>, <0.45, 1.5, 0>}}
      }
      texture {
        material_map {
          tga "tcpmap.tga" once
          texture {TD_Tex2}
          texture {TD_Tex3}
        }
        translate <-0.5, -0.5, 0>
        rotate <90,0,0>
        scale 2.05
      }
    }
    object {
      cylinder {<0,1,0>, <0,1.025,0>, 0.75}
      texture {
        pigment {colour rgb 0.15}
      }
    }
    object {TD_Screen}
    object {TD_ScreenFrame}
  }
}


#declare TieDefender = object {
  union {
    object {TD_Panel translate <2,0,-1.5> rotate <0,0,90>}
    object {TD_Panel translate <2,0,-1.5> rotate <0,0,-30> scale <1,1,1>}
    object {TD_Panel translate <2,0,-1.5> rotate <0,0,-30> scale <-1,1,1>}
    object {TD_Cockpit}
  }
  scale 0.7
}
